@@ -281,6 +281,7 @@ function isEntity(obj) {
 function isDimensionEntity(obj) {
     return isDimAlignedEntity(obj)
         || isDimAngularEntity(obj)
+        || isDimArcLengthEntity(obj)
         || isDimDiametricEntity(obj)
         || isDimLinearEntity(obj)
         || isDimOrdinateEntity(obj)
@@ -342,10 +343,40 @@ function isDimRadialEntity(obj) {
  * Checks if the given object is an angular dimension entity.
  * 
  * \return true if the given object is an angular dimension entity
- * (RDimAngularEntity).
+ * (RDimAngular2LEntity or RDimAngular3PEntity).
  */
 function isDimAngularEntity(obj) {
-    return isOfType(obj, RDimAngularEntity) || isOfType(obj, RDimAngularEntityPointer);
+    return isDimAngular2LEntity(obj) || isDimAngular3PEntity(obj);
+}
+
+/**
+ * Checks if the given object is an angular dimension from 2 lines entity.
+ *
+ * \return true if the given object is an angular dimension entity
+ * (RDimAngular2LEntity).
+ */
+function isDimAngular2LEntity(obj) {
+    return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+}
+
+/**
+ * Checks if the given object is an angular dimension from 3 points entity.
+ *
+ * \return true if the given object is an angular dimension entity
+ * (RDimAngular3PEntity).
+ */
+function isDimAngular3PEntity(obj) {
+    return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+}
+
+/**
+ * Checks if the given object is an arc length dimension entity.
+ *
+ * \return true if the given object is an arc length dimension entity
+ * (RDimArcLengthEntity).
+ */
+function isDimArcLengthEntity(obj) {
+    return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
 }
 
 /**
@@ -831,6 +862,12 @@ function entityTypeToString(type, plural) {
         return plural ? qsTr("Aligned Dimensions") : qsTr("Aligned Dimension");
     case RS.EntityDimAngular:
         return plural ? qsTr("Angular Dimensions") : qsTr("Angular Dimension");
+    case RS.EntityDimAngular2L:
+        return plural ? qsTr("2 Line Angular Dimensions") : qsTr("2 Line Angular Dimension");
+    case RS.EntityDimAngular3P:
+        return plural ? qsTr("3 Point Angular Dimensions") : qsTr("3 Point Angular Dimension");
+    case RS.EntityDimArcLength:
+        return plural ? qsTr("Arc Dimension") : qsTr("Arc Dimension");
     case RS.EntityDimDiametric:
         return plural ? qsTr("Diametric Dimensions") : qsTr("Diametric Dimension");
     case RS.EntityDimOrdinate:
@@ -877,70 +914,6 @@ function entityTypeToString(type, plural) {
     }
 }
 
-//function getEntityTypeProperties(type) {
-//    switch (type) {
-//    case RS.EntityAll:
-//        return REntity.getStaticPropertyTypeIds();
-//    case RS.EntityBlockReferenceEntity:
-//        return RBlockReferenceEntity.getStaticPropertyTypeIds();
-//    case RS.EntityArc:
-//        return RArcEntity.getStaticPropertyTypeIds();
-//    case RS.EntityAttribute:
-//        return RAttributeEntity.getStaticPropertyTypeIds();
-//    case RS.EntityAttributeDefinition:
-//        return RAttributeDefinitionEntity.getStaticPropertyTypeIds();
-//    case RS.EntityCircle:
-//        return RCircleEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimension:
-//        return RDimensionEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimAligned:
-//        return RDimAlignedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimAngular:
-//        return RDimAngularEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimDiametric:
-//        return RDimDiametricEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimOrdinate:
-//        return RDimOrdinateEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimRotated:
-//        return RDimRotatedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimRadial:
-//        return RDimRadialEntity.getStaticPropertyTypeIds();
-//    case RS.EntityEllipse:
-//        return REllipseEntity.getStaticPropertyTypeIds();
-//    case RS.EntityHatch:
-//        return RHatchEntity.getStaticPropertyTypeIds();
-//    case RS.EntityImage:
-//        return RImageEntity.getStaticPropertyTypeIds();
-//    case RS.EntityLeader:
-//        return RLeaderEntity.getStaticPropertyTypeIds();
-//    case RS.EntityLine:
-//        return RLineEntity.getStaticPropertyTypeIds();
-//    case RS.EntityPoint:
-//        return RPointEntity.getStaticPropertyTypeIds();
-//    case RS.EntityPolyline:
-//        return RPolylineEntity.getStaticPropertyTypeIds();
-//    case RS.EntitySolid:
-//        return RSolidEntity.getStaticPropertyTypeIds();
-//    case RS.EntityTrace:
-//        return RTraceEntity.getStaticPropertyTypeIds();
-//    case RS.EntityViewport:
-//        return RViewportEntity.getStaticPropertyTypeIds();
-//    case RS.EntityRay:
-//        return RRayEntity.getStaticPropertyTypeIds();
-//    case RS.EntityXLine:
-//        return RXLineEntity.getStaticPropertyTypeIds();
-//    case RS.EntitySpline:
-//        return RSplineEntity.getStaticPropertyTypeIds();
-//    case RS.EntityTextBased:
-//        return RTextBasedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityText:
-//        return RTextEntity.getStaticPropertyTypeIds();
-//    case RS.EntityUnknown:
-//    default:
-//        return [];
-//    }
-//}
-
 /**
  * Checks the type of the given object.
  *
@@ -1411,27 +1384,6 @@ Array.prototype.sortNumerical = function() {
     Array.prototype.sort.call(this, function(a,b) { return a - b });
 }
 
-//Array.alphaNumericalSorter = function(a, b) {
-//    var aVal = parseInt(a);
-//    var bVal = parseInt(b);
-//    if (isNaN(aVal) && isNaN(bVal)) {
-//        // alphabetical:
-//        return a.localeCompare(b);
-//    }
-//    else if (isNaN(aVal)) {
-//        // text before numbers:
-//        return -1;
-//    }
-//    else if (isNaN(bVal)) {
-//        // numbers after texts:
-//        return 1;
-//    }
-//    else {
-//        // nummerical:
-//        return aVal - bVal;
-//    }
-//};
-
 /* alphanum.js (C) Brian Huisman
  * Based on the Alphanum Algorithm by David Koelle
  * The Alphanum Algorithm is discussed at http://www.DaveKoelle.com
@@ -1453,43 +1405,52 @@ Array.prototype.sortNumerical = function() {
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 Array.alphaNumericalSorter = function(a, b) {
-    function chunkify(t) {
-        var tz = new Array();
-        var x = 0, y = -1, n = 0, i, j;
+    if (RS.getSystemId()==="linux") {
+        // workaround for QCollator / Linux bug:
+        function chunkify(t) {
+            var tz = [];
+            var x = 0, y = -1, n = 0, i, j;
 
-        while (i = (j = t.charAt(x++)).charCodeAt(0)) {
-            var m = (i == 46 || (i >=48 && i <= 57));
-            if (m !== n) {
-                tz[++y] = "";
-                n = m;
+            while (i = (j = t.charAt(x++)).charCodeAt(0)) {
+                var m = (i == 46 || (i >=48 && i <= 57));
+                if (m !== n) {
+                    tz[++y] = "";
+                    n = m;
+                }
+                tz[y] += j;
             }
-            tz[y] += j;
+            return tz;
         }
-        return tz;
-    }
 
-    var aa = chunkify(a.toLowerCase());
-    var bb = chunkify(b.toLowerCase());
+        var aa = chunkify(a.toLowerCase());
+        var bb = chunkify(b.toLowerCase());
 
-    for (x = 0; aa[x] && bb[x]; x++) {
-        if (aa[x] !== bb[x]) {
-            var c = Number(aa[x]), d = Number(bb[x]);
-            if (c == aa[x] && d == bb[x]) {
-                return c - d;
-            } else return (aa[x] > bb[x]) ? 1 : -1;
+        for (x = 0; aa[x] && bb[x]; x++) {
+            if (aa[x] !== bb[x]) {
+                var c = Number(aa[x]), d = Number(bb[x]);
+                if (c == aa[x] && d == bb[x]) {
+                    return c - d;
+                } else return (aa[x] > bb[x]) ? 1 : -1;
+            }
         }
+
+        return aa.length - bb.length;
+    }
+    else {
+        // Windows / macOS support alphanumerical sorting and
+        // sorting with international characters as well:
+        return RS.compareAlphanumerical(a, b);
     }
-    return aa.length - bb.length;
 };
 
 /**
  * Sorts this array with string items (case insensitive)
  */
-Array.prototype.sortCaseInsensitive = function() {
-    Array.prototype.sort.call(this, function (a, b) {
-        return a.toLowerCase().localeCompare(b.toLowerCase());
-    });
-};
+//Array.prototype.sortCaseInsensitive = function() {
+//    Array.prototype.sort.call(this, function (a, b) {
+//        return a.toLowerCase().localeCompare(b.toLowerCase());
+//    });
+//};
 
 /* Finds the intersection of two sorted arrays.
  *
@@ -2196,7 +2157,6 @@ function restoreOverrideCursor() {
 }
 
 function initUserShortcuts() {
-    var settings = RSettings.getQSettings();
     var keys = RSettings.getAllKeys("Shortcuts");
 
     var i, key, action;
@@ -2207,14 +2167,25 @@ function initUserShortcuts() {
         if (isNull(action)) {
             continue;
         }
-        var scStringList = settings.value("Shortcuts/" + key);
+
+        var match = action.getScriptFile().contains("OpenFile");
+
+        var scStringList = RSettings.getValue("Shortcuts/" + key);
+
+        if (match) qDebug("scStringList", scStringList);
 
         // explicitely no shortcuts:
         if (isNull(scStringList)) {
+            if (match) qDebug("explicitely no shortcuts");
             action.setShortcuts([]);
             continue;
         }
 
+        if (match) qDebug("setting shortcuts to ", scStringList);
+
+        //action.setShortcutsFromStrings(scStringList);
+        //action.setShortcuts(scStringList);
+
         var scList = [];
         for (var k=0; k<scStringList.length; k++) {
             var sc = new QKeySequence(scStringList[k]);
@@ -2231,7 +2202,7 @@ function initUserShortcuts() {
         if (isNull(action)) {
             continue;
         }
-        var cmStringList = settings.value("Commands/" + key);
+        var cmStringList = RSettings.getValue("Commands/" + key);
 
         // explicitely no commands:
         if (isNull(cmStringList)) {
